Encoding: UTF-8
Package: genSurv
Type: Package
Version: 1.0.6
Date: 2026-04-05
Title: Generating Multi-State Survival Data
Authors@R: c(
	person(
		given = "Artur",
		family = "Araujo",
		role = c("aut", "cre"),
		email = "artur.stat@gmail.com",
		comment = c(ORCID = "0000-0003-1419-4208")
	),
	person(
		given = "Luis",
		family = "Meira-Machado",
		role = "aut",
		email = "lmachado@math.uminho.pt",
		comment = c(ORCID = "0000-0002-8577-7665")
	),
	person(
		given = "Susana",
		family = "Faria",
		role = "aut",
		email = "sfaria@math.uminho.pt",
		comment = c(ORCID = "0000-0001-8014-9902")
	) )
Depends: R (>= 2.12.0)
Suggests: survival
Description: Generation of survival data with one (binary)
  time-dependent covariate.  Generation of survival data arising
  from a progressive illness-death model.
License: GPL-3
URL: https://github.com/arturstat/genSurv
BugReports: https://github.com/arturstat/genSurv/issues
LazyLoad: yes
NeedsCompilation: yes
Packaged: 2026-04-05 16:48:33 UTC; User
Author: Artur Araujo [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1419-4208>),
  Luis Meira-Machado [aut] (ORCID:
    <https://orcid.org/0000-0002-8577-7665>),
  Susana Faria [aut] (ORCID: <https://orcid.org/0000-0001-8014-9902>)
Maintainer: Artur Araujo <artur.stat@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-05 17:30:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-08 01:04:39 UTC; unix
Archs: genSurv.so.dSYM
