useDynLib(genSurv, .registration=TRUE)
importFrom("stats", rexp, runif)
export(genCMM, genCPHM, genTDCM, genTHMM)
export(as.CMM, as.TDCM, as.THMM)
export(is.CMM, is.TDCM, is.THMM)
S3method(as.CMM, default)
S3method(as.CMM, CMM)
S3method(as.CMM, TDCM)
S3method(as.CMM, THMM)
S3method(as.TDCM, default)
S3method(as.TDCM, TDCM)
S3method(as.TDCM, CMM)
S3method(as.TDCM, THMM)
S3method(as.THMM, default)
S3method(as.THMM, THMM)
S3method(as.THMM, CMM)
S3method(as.THMM, TDCM)
